import { jsxs, Fragment, jsx } from 'react/jsx-runtime';
import { InlineField } from '../Forms/InlineField.js';
import { InlineSwitch } from '../Switch/Switch.js';

const LABEL_WIDTH = 26;
const HttpProxySettings = ({
  dataSourceConfig,
  onChange,
  showForwardOAuthIdentityOption = true
}) => {
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsxs("div", { className: "gf-form-inline", children: [
      /* @__PURE__ */ jsx(InlineField, { label: "TLS Client Auth", labelWidth: LABEL_WIDTH, disabled: dataSourceConfig.readOnly, children: /* @__PURE__ */ jsx(
        InlineSwitch,
        {
          id: "http-settings-tls-client-auth",
          value: dataSourceConfig.jsonData.tlsAuth || false,
          onChange: (event) => onChange({ ...dataSourceConfig.jsonData, tlsAuth: event.currentTarget.checked })
        }
      ) }),
      /* @__PURE__ */ jsx(
        InlineField,
        {
          label: "With CA Cert",
          tooltip: "Needed for verifying self-signed TLS Certs",
          labelWidth: LABEL_WIDTH,
          disabled: dataSourceConfig.readOnly,
          children: /* @__PURE__ */ jsx(
            InlineSwitch,
            {
              id: "http-settings-ca-cert",
              value: dataSourceConfig.jsonData.tlsAuthWithCACert || false,
              onChange: (event) => onChange({ ...dataSourceConfig.jsonData, tlsAuthWithCACert: event.currentTarget.checked })
            }
          )
        }
      )
    ] }),
    /* @__PURE__ */ jsx("div", { className: "gf-form-inline", children: /* @__PURE__ */ jsx(InlineField, { label: "Skip TLS Verify", labelWidth: LABEL_WIDTH, disabled: dataSourceConfig.readOnly, children: /* @__PURE__ */ jsx(
      InlineSwitch,
      {
        id: "http-settings-skip-tls-verify",
        value: dataSourceConfig.jsonData.tlsSkipVerify || false,
        onChange: (event) => onChange({ ...dataSourceConfig.jsonData, tlsSkipVerify: event.currentTarget.checked })
      }
    ) }) }),
    showForwardOAuthIdentityOption && /* @__PURE__ */ jsx("div", { className: "gf-form-inline", children: /* @__PURE__ */ jsx(
      InlineField,
      {
        label: "Forward OAuth Identity",
        tooltip: "Forward the user's upstream OAuth identity to the data source (Their access token gets passed along).",
        labelWidth: LABEL_WIDTH,
        disabled: dataSourceConfig.readOnly,
        children: /* @__PURE__ */ jsx(
          InlineSwitch,
          {
            id: "http-settings-forward-oauth",
            value: dataSourceConfig.jsonData.oauthPassThru || false,
            onChange: (event) => onChange({ ...dataSourceConfig.jsonData, oauthPassThru: event.currentTarget.checked })
          }
        )
      }
    ) })
  ] });
};

export { HttpProxySettings };
//# sourceMappingURL=HttpProxySettings.js.map
